#!/usr/local/bin/python3.9
# -*- coding: utf-8 -*-

from decat import main

if __name__ == '__main__':
    main()
